@@ -1,4 +1,5 @@
 from colorama import Fore, Style
+from .terminal import Terminal
 
 class ProgressBar:
     def __init__(self, total: int) -> None:
@@ -9,13 +10,17 @@ class ProgressBar:
 
     def __str__(self) -> str:
         s = (
-           f'\r'
+           '\r'
            f'{Fore.GREEN}{"━" * int(self.procentage / 4)}'
            f'{Fore.RED}{"─" * (25 - int(self.procentage / 4))}'
            f'{Fore.CYAN} {self.current}{Fore.BLUE}/{Fore.CYAN}{self.total} '
            f'{Fore.YELLOW}{self.procentage}%'
            f'{Style.RESET_ALL}'
         )
+        if self.current == self.total:
+            Terminal._updating_line = ''
+        else:
+            Terminal._updating_line = s
         return s
 
     def __iadd__(self, value: int) -> 'ProgressBar':
@@ -29,6 +34,7 @@ class ProgressBar:
     def update(self, current) -> None:
         if current > self.total:
             self.current = self.total
+        else:
             self.current = current
         self.procentage = round(current * 100 / self.total, 2)
         print(self, end='')
